<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation>备份</translation>
    </message>
</context>
<context>
    <name>DrawMapWidget</name>
    <message>
        <source>File error</source>
        <translation type="unfinished">文件错误</translation>
    </message>
    <message>
        <source>Cannot open file &apos;%1&apos; for writing</source>
        <translation type="unfinished">无法打开文件 &apos;%1&apos; 写入</translation>
    </message>
    <message>
        <source>Cannot read file &apos;%1&apos;</source>
        <translation type="unfinished">无法读取文件 &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>从不</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>每 %1 个回合</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>无法使用此弹药设置</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>修改游戏设置</translation>
    </message>
    <message>
        <source>Edit weapons</source>
        <translation>修改武器</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation>使用此项则游戏框架自动选择武器配备</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 已经从您的忽略列表中移除</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 已经添加到您的忽略列表中</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 已经从您的朋友列表中移除</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 已经添加到您的朋友列表中</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>无法录入文件 %1</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>开启服务端出现错误</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="obsolete">新</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>请选择一个记录</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>默认队伍</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation>刺猬大作战回放文件</translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation>刺猬大作战存档文件</translation>
    </message>
    <message>
        <source>Demo name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>zh_CN.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>DEMO %1 打不开</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>地图</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>过滤</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小型</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中型</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大型</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>洞穴</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>险峻</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>小型隧道</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>中型隧道</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>大型隧道</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>小型漂浮岛屿</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>中型漂浮岛屿</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>大型漂浮岛屿</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation>作种</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>设定</translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>没找到主机。请检查主机名和端口设置。</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>连接被拒绝</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>退出原因：</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>房间损坏</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>被踢出</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">您的昵称%1
在Hedgewars.org已注册
请输入您的密码
或选择另一个昵称:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 进入这个房间了</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 加入了</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 离开了(%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 离开了</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation>您的昵称%1
在Hedgewars.org已注册
请输入您的密码
或从游戏配置中选择另一个昵称:</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished">昵称</translation>
    </message>
    <message>
        <source>Some one already uses
 your nickname %1
on the server.
Please pick another nickname:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>渲染文字时SDL_ttf 返回错误，可能有关freetype2的bug。建议升级 freetype。</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">服务器信息：</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">设定信息</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>清空账户缓存</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>获取数据</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>最新版本的服务器信息</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>之前版本的服务器信息</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>最新版本的通讯协议号码:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>MOTD预览:</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>设定数据</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>连接中...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>读取</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation>读取已经绘制的地图</translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation type="obsolete">绘制的地图 (*.hwmap);;全部文件 (*.*)</translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation>保存绘制的地图</translation>
    </message>
    <message>
        <source>Drawn Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>进阶</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;最佳射手奖给与 &lt;b&gt;%1&lt;/b&gt;：伤害 &lt;b&gt;%2&lt;/b&gt;点。&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;最佳杀手是 &lt;b&gt;%1&lt;/b&gt;单回合击杀刺猬数:&lt;b&gt;%2&lt;/b&gt;&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;本轮总共有&lt;b&gt;%1&lt;/b&gt;只刺猬被击杀&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>细节</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>健康值图形</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>排名</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>最佳射手&lt;b&gt;%1&lt;/b&gt;为同族制造了&lt;b&gt;%2&lt;/b&gt;点创伤</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>最佳杀手&lt;b&gt;%1&lt;/b&gt; 完成了单回合&lt;b&gt;%2&lt;/b&gt;次击杀</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>总共&lt;b&gt;%1&lt;/b&gt;只刺猬在本轮失去生命。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation>
            <numerusform>(%1 击杀)</numerusform>
        </translation>
    </message>
    <message>
        <source>(%1 kills)</source>
        <translation type="obsolete">(%1 击杀)</translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt;以为给自己的刺猬造成 &lt;b&gt;%2&lt;/b&gt; 点创伤是小意思。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; 整垮了 &lt;b&gt;%2&lt;/b&gt; 只自己的刺猬。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; 受惊了，共计 &lt;b&gt;%2&lt;/b&gt; 次放弃。</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>单机游戏（在一台电脑上）</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>网络游戏（通过网络）</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation>点击同色作为同一组的友军。控制权不分享，但是共同胜利/失败。</translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation>有些武器可能威力低下但是有毁灭性的效果。比如沙漠之鹰能把多个刺猬打入水中。</translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation>加入不确定怎么做，不要浪费弹药，跳过此回合。但是注意突然时间！</translation>
    </message>
    <message>
        <source>Want to save ropse? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="obsolete">保存绳子？在半空释放然后再次射出。只要不接触地面停止就可以继续使用同一根不会浪费！</translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation>如果您确定好了一个昵称不想让别人使用，那么在  http://www.hedgewars.org/. 注册一个帐号吧</translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation>厌倦了默认的玩法？试试任务——</translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation>默认情况下游戏记录最后的游戏作为Demo，选择单机游戏——然后Demo——然后点击右下角开始回放或者整理。</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation>刺猬大作战是一个开放源代码的免费软件，它充分利用了我们的业余时间。如果您有问题，到论坛来吧，不过7×24小时支持不可能！</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation>刺猬大作战是一个开放源代码的免费软件，它充分利用了我们的业余时间。如果您喜欢它，我们接受您的捐赠/感谢！</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation>刺猬大作战是一个开放源代码的免费软件，它充分利用了我们的业余时间。与他人分享它吧！</translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation>官方的竞赛一直存在。临近时去  http://www.hedgewars.org/  即可看到。</translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation>Hedgewars 被翻译成多种语言，中文是刺猬大作战——同样为翻译名。如果您的语言翻译有什么缺失/过时/遗漏或任何问题，来联系我们吧！</translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation>刺猬大作战可以运行的操作系统包括：GNU/Linux、Mac OS X、MicroSoft Windows。</translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation>您可以建立自己的网络游戏/局域网游戏。不仅限于 &quot;简单游戏&quot; 选项。</translation>
    </message>
    <message>
        <source>Create an account on http://www.hedgewars.org/ to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation type="obsolete">在官方服务器 http://www.hedgewars.org/ 建立自己的帐号——就能一直使用最喜欢的昵称</translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation>最好玩一个小时就休息一下，如果你要继续用电脑。</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation>假如你的显卡不能提供OpenGL硬件加速，试着用降低效果的方式运行</translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation>我们接受意见和建设性反馈。假如您有好电子或者不喜欢的东西，告诉我们！</translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation>特别是网络游戏，请有礼貌记住对方也和您一样是人！</translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation>特别游戏模式“吸血“、”因果报应“需要全新的战术。现在自定义游戏里试试！</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Windows版本的刺猬大作战支持Xfire。添加它到游戏列表里让您的朋友看到。</translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation>您不应该在不属于您的计算机上安装刺猬大作战——比如学校/工作场所。</translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation>刺猬大作战适合短时间休息，不需要太多刺猬挤在大地图上。</translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation>制作这个游戏时不曾伤害任何刺猬</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before launching the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation type="obsolete">在运行游戏前连接游戏板</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation>刺猬大作战是开放源代码的免费软件，用我们的闲暇时间创造。如果有人卖给你，那么应该把钱拿回来！</translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation>在 %1 建立一个帐号阻止其他人使用你喜欢的名称在官方服务器游戏。</translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation>三种跳跃方式。点击[高跳]两次做出跳跃高度极限的后空翻。</translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation>害怕掉下悬崖？按住[精确]后再点击[左][右]就会只转身，不移动位置。</translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation>有些武器需要特殊策略或者仅仅是大量的练习，假如你一次失去准星，也不要放弃。</translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation>多数武器不会在接触水之后生效。归巢的蜜蜂和蛋糕是例外。</translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation>老干酪发射器造成小规模爆炸，然后产生随风移动的有毒云雾——能一次毒害多个刺猬。</translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation>钢琴攻击是最大威力的空袭。弹奏钢琴的刺猬会跟着钢琴返回天堂。</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="obsolete">归巢的蜜蜂有些技巧。它的回转半径和初速有关，最好不用全力发射。</translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation>黏着地雷是创造小范围连锁反应的绝佳武器。</translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation>锤是桥梁上/分界处最佳武器之一，只是刚刚好把刺猬打陷——如果没底就没办法了。</translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation>假如对方刺猬把你堵住了，一锤打下去让自己轻松些。</translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation>蛋糕的最大行走距离取决于地表。也可按下[攻击键]激活起爆。</translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation>火焰喷射器是一种武器，也是一种开路机器。</translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="obsolete">燃烧瓶可以短时阻止刺猬通过特定区域（比如通道或平台）</translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation>想要知道谁是此游戏的幕后人员？点击主菜单的Hedgewars Logo就可以看到贡献者名单。</translation>
    </message>
    <message>
        <source>Like hedgewars? Become a fan on %1 or join our group at %2. You could follow us on %3 as well!</source>
        <comment>Tips</comment>
        <translation type="obsolete">喜欢刺猬大作战（hedgewars）？那么加入我们 %1 或者 %2.。你可以在 %3 跟随我们！</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>你可以在（ 我的文档\Hedgewars）里找到设置文件。可以创建备份，但不要手动修改。</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="obsolete">你可以在家目录找到 .hedgewars。可以创建备份，但不要手动修改。</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation>在游戏开始前连接游戏手柄才能用于操控</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation>加入你的显卡不能使用OpenGL硬件加速，请升级相应驱动。</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or join our group at %2. You could follow us on %3 as well!</source>
        <comment>Tips</comment>
        <translation type="obsolete">喜欢刺猬大作战(Hedgewars)吗？加入 %2 ，成为 %1 粉丝，也可以在  %3 跟随我们！</translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation>欢迎你自己绘制墓碑，帽子（头饰），旗帜或者地图，主题！但是记住，如果要在网上使用，你的必须把它们分享出来。</translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation>非常想要一个帽子？捐赠的话就给你！</translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation>保持显卡驱动最新避免可能的麻烦。</translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation>你可以使用网络浏览器或已存在的文件关联刺猬大作战的相关文件（比如存档和回放）</translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation>想要节省绳子？放开绳子之后再次发射，只要你不曾脱离绳子接触接触地面就可以继续使用同一根！</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation>喜欢刺猬大作战Hedgewars吗？来 %1 或者 %2 追随我们吧！</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>在家目录的&quot;Library/Application Support/Hedgewars&quot;找到刺猬的配置文件。备份随你，但是不要手动编辑。</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>在家目录的&quot;.hedgewars&quot;找到刺猬的配置文件。备份随你，但是不要手动编辑。</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgewars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the Molotov or Flame Thrower to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. Its turn radius depends on its velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloadable Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>请选择一个服务器</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>房间管理</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">错误</translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation type="unfinished">请键入房间名</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>局域网游戏</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>官方服务器</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>新队伍</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>修改队伍设定</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>删除队伍</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">新武器配置</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">修改武器配置</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">删除武器配置</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>您不能在队伍选择界面修改队伍。请返回主页面进行添加、修改、删除队伍等操作。</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation>新框架</translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation>修改框架</translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation>删除框架</translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation>新武器配置</translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation>修改武器配置</translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation>删除武器配置</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>重命名对话框</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>输入新的文件名:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>不能改变名字</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>不能删除文件</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>请从列表选择记录</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>建立</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>加入</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>管理员功能</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>房间名:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>游戏正在大厅中。
您可以加入等待游戏开始。</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>游戏正在进行中。
您可以加入观战但必须等游戏结束才能参与游戏。</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 是房主，他可以调整设置、开始游戏。</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>随机地图</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>游戏可以在预先创建或者随机产生的地图上进行。</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>游戏设置包括一般选项例如回合时间，突然死亡或吸血模式。</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>武器配置包括可以选用的武器和弹药数量。</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>有 %1 个客户端连接到这个房间。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>有 %1 个队伍加入这个房间。</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>请键入房间名</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>请从列表选中房间</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>随机迷宫</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>游戏状态</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>规则</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>你要加入的游戏已经开始了。
还要进入房间吗？</translation>
    </message>
    <message numerus="yes">
        <source>%1 players online</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation>新模式</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>保卫你的城堡，破坏对手的，努力吧！</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>队伍开始在对手的地盘，努力！</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>地面无法破坏！</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation type="obsolete">添加不可毁坏地边界</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>低重力</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>激光瞄准辅助</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>每个刺猬都有一个力场</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">开启随机地雷</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>伤害的80%变成自身力量</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>分担你的对手的疼痛</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>你的刺猬不能移动，检验你射击技巧的时候到了</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>随机</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒钟</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>随机出场顺序</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>国王不能死!!</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>在开局前手动放置刺猬</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>同色队伍共享所有弹药。</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>禁止随机生成地图使用梁</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>禁止随机生成地图使用地面物体</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>AI 死亡再生</translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation>攻击不会结束当前回合</translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation>每回合开始武器自动重置到默认设定</translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation>每个刺猬都有独立的弹药，非团队分享</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation>所有活着的刺猬回合结尾时彻底恢复健康。</translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation>不用担心风的影响了。</translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation>风无所不在。</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>备份</translation>
    </message>
    <message>
        <source>Teams in each clan take successive turns sharing their turn time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructible border around the terrain</source>
        <translation>添加不可毁坏地边界</translation>
    </message>
    <message>
        <source>Add an indestructible border along the bottom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新模式</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>备份</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>快速游戏 (使用预设对抗电脑)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>多人游戏 (热坐对抗朋友或AI)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>训练模式 (一系列训练任务)。开发中</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demo (观看记录的Demo)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>读取 (读取之前保存的游戏)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation>战役模式 ——开发中</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>踢</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>限制参与</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>限制团队插件</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>屏蔽</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>跟随</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>添加朋友</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>取消忽略</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>移除朋友</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">更新</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>启动时检查程序升级</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>开启游戏音效</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>游戏全屏幕</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>显示帧率 (FPS)</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>另一种伤害显示方式</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>开启游戏音乐</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>前端界面全屏幕</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>记录名称中包含具体时间和日期</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">降低显示效果</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>显示武器菜单提示</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>开启前端界面音效</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>开启前端界面音乐</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>前端界面效果</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>生成地图...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>玩家</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Lv 级别</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(系统默认)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>生成迷宫</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>任务</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>社区</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>任意</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>大厅中</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>进行中</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">默认</translation>
    </message>
    <message>
        <source>Pro mode</source>
        <translation type="obsolete">高手模式</translation>
    </message>
    <message>
        <source>Shoppa</source>
        <translation type="obsolete">绳子党</translation>
    </message>
    <message>
        <source>Basketball</source>
        <translation type="obsolete">篮球</translation>
    </message>
    <message>
        <source>Minefield</source>
        <translation type="obsolete">雷区</translation>
    </message>
    <message>
        <source>Barrel mayhem</source>
        <translation type="obsolete">炼狱场</translation>
    </message>
    <message>
        <source>Tunnel hogs</source>
        <translation type="obsolete">刺猬洞</translation>
    </message>
    <message>
        <source>Crazy</source>
        <translation type="obsolete">疯狂刺猬</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation>手绘地图</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Side-by-side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top-Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wiggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>成员</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>城堡模式</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>键位绑定</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>队伍</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>音频/视频选项</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>玩家队伍</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>局域网络游戏</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">武器</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>游戏修改</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>队伍设定</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>杂项</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation>游戏框架和武器配置</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Net nick</source>
        <translation>网络游戏昵称</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>This program is distributed under the GNU General Public License</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>分辨率</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS 上限</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>开发者:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>艺术:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>翻译:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>特别感谢:</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>服务器名:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>服务器端口:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主机:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>端口:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>声音:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>初始音量</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>伤害修正值</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>回合时间</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>初始生命值</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>死亡模式倒计时</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>设置名称：</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>箱子降落</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>游戏设置</translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation>布雷时间</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>地雷</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% 地雷故障</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>墓碑</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>旗帜</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>声音</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Locale</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>需要重新启动游戏方可应用</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>爆炸物</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>提示:</translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>当前运行的为开发版本，不同其他版本兼容。功能或许损坏、不完整。请自行承担风险！</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>图像质量</translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation>死亡模式水位上涨</translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation>死亡模式健康降低</translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation>% 绳长</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation>% 生命箱</translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation>生命箱的值数</translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation type="obsolete">游戏</translation>
    </message>
    <message>
        <source>Stereo rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">密码</translation>
    </message>
    <message>
        <source>% Get Away Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>无名</translation>
    </message>
    <message>
        <source>hedgehog %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>刺猬大作战 %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>打不开数据文件目录:
%1
请检查</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>与服务器的连接丢失</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">不能删除默认武器设定</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>真的删除这个武器设定吗?</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">不能更改默认的武器设定</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>不能覆盖默认的武器配置 &apos;%1&apos;</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation>所有相关文件已经设定。</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>队伍</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation>真的要删除队伍？</translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation>游戏框架</translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation>无法删除默认游戏框架 &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation>文件关联失败</translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation>真的删除此游戏框架？</translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation>无法删除武器配置%1&apos;!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>无法创建路径 %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>昵称</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>请输入您的昵称</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Setup</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>播放 demo</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>上场！</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>开始服务端</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>读取</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>指定</translation>
    </message>
    <message>
        <source>default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>准备好了</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>随机分配队伍</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation>相关文件扩展</translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>房间名</translation>
    </message>
    <message>
        <source>C</source>
        <translation>人数限制</translation>
    </message>
    <message>
        <source>T</source>
        <translation>时间限制</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>创建者</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>地图</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>规则</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>武器设置</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>空中支援几率</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>弹药箱</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>延迟回合数</translation>
    </message>
    <message>
        <source>new</source>
        <translation>新</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished">备份</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>无法开始服务端: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>无法运行引擎: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Fort Mode</source>
        <translation>城堡模式</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>团体行动</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>固实地面</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>添加边界</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>低重力</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>激光瞄准</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>刀枪不入</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">布置地雷</translation>
    </message>
    <message>
        <source>Vampirism</source>
        <translation>吸血鬼</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>因果报应</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>射术</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>随机顺序</translation>
    </message>
    <message>
        <source>King</source>
        <translation>国王模式</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>手动放置刺猬</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>团队共享弹药</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>禁止梁</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>禁止地面物件</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation>AI生存模式</translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation>无限攻击</translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation>重置武器</translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation>每个刺猬的弹药</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation>重置生命值</translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation>禁止风力作用</translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation>让风来地更猛烈吧！</translation>
    </message>
    <message>
        <source>Tag Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bottom Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>上</translation>
    </message>
    <message>
        <source>left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>down</source>
        <translation>下</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>攻击</translation>
    </message>
    <message>
        <source>put</source>
        <translation>放</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>切换</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>定时1秒</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>定时2秒</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>定时3秒</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>定时4秒</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>定时5秒</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>截取</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>寻找刺猬</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>弹药菜单</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>降低音量</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>提高音量</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>改变模式</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>刺猬大作战
信息</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>聊天记录</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>练习瞄准</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>缩小</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>重置</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>远跳</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>高跳</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>slot 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>基本控制</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>武器控制</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>镜头和光标控制</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>移动您的刺猬同时瞄准：</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>使用跳跃越过沟渠、障碍：</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>使用选择的武器开火、使用物品：</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>选取一个武器或者瞄准光标下的地点：</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>切换到您当前活动的刺猬（如果可用）：</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>选择一个武器或物品：</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>设置定时炸弹等武器起爆时间：</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>移动镜头到选中的刺猬：</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>不用鼠标移动光标或镜头：</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>调整镜头放大倍数：</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>同队友或全部参与者对话：</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>暂停、继续或离开游戏：</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>调整游戏时音量：</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>全屏模式：</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>截图：</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>切换刺猬头顶标签的显示方式：</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Axis轴</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(上)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(下)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>帽子</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(左)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(右)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>按键</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>键盘</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>鼠标：左键</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>鼠标：中键</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>鼠标：右键</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>鼠标滚轮：向上</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>鼠标滚轮：向下</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>退格键</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Num Lock / Clear</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>回车</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停键</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>ESC键(退出键)</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>空格键</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Del(删除键)</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>小键盘0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>小键盘1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>小键盘2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>小键盘3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>小键盘4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>小键盘5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>小键盘6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>小键盘7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>小键盘8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>小键盘9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>小键盘.</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>小键盘/</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>小键盘*</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>小键盘-</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>小键盘+</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>回车键</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>等于</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>插入键</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home键</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End键</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>向上翻页键</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>向下翻页键</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>小键盘数字锁</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>大小写切换键</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll Lock键</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>右Shift键</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>左Shift键</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>右Ctrl键</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>左Ctrl键</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>右Alt键</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>左Alt键</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>右meta键</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>左meta键</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>A 键</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>B 键</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>X 键</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Y 键</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>LB 键</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>RB 键</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>返回键</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>开始键</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>左摇杆</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>右摇杆</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>右(左摇杆)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>左(左摇杆)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>下(左摇杆)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>上(左摇杆)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>左制动</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>右制动</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>下(右摇杆)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>上(右摇杆)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>右(右摇杆)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>左(右摇杆)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad板</translation>
    </message>
</context>
</TS>
